@@ -98,9 +98,10 @@ public:
 
     virtual FontDescription fontDescription() const = 0;
 };
-}
 
-Q_DECLARE_OPERATORS_FOR_FLAGS(Kleo::KeyFilter::MatchContexts)
+Q_DECLARE_OPERATORS_FOR_FLAGS(KeyFilter::MatchContexts)
+
+}
 
 #include <QObject>
 
