@@ -159,6 +159,8 @@ private:
 
 class DirectoryServicesWidget::Private
 {
+    Q_DISABLE_COPY(Private)
+
     DirectoryServicesWidget *const q;
 
     struct {
@@ -173,7 +175,7 @@ class DirectoryServicesWidget::Private
     bool readOnly = false;
 
 public:
-    Private(DirectoryServicesWidget *qq)
+    explicit Private(DirectoryServicesWidget *qq)
         : q(qq)
     {
         auto mainLayout = new QVBoxLayout{q};
@@ -183,7 +185,8 @@ public:
         gridLayout->setRowStretch(1, 1);
 
         keyserverModel = new KeyserverModel{q};
-        ui.keyserverList = new QListView();
+        ui.keyserverList = new QListView{q};
+        ui.keyserverList->setAccessibleName(i18nc("@label", "Directory services"));
         ui.keyserverList->setModel(keyserverModel);
         ui.keyserverList->setModelColumn(0);
         ui.keyserverList->setSelectionBehavior(QAbstractItemView::SelectRows);
@@ -217,7 +220,7 @@ public:
         ui.newButton->setMenu(menu);
         groupsButtonLayout->addWidget(ui.newButton);
 
-        ui.editButton = new QPushButton(i18nc("@action:button", "Edit"));
+        ui.editButton = new QPushButton(i18nc("@action:button", "Edit"), q);
         ui.editButton->setToolTip(i18nc("@info:tooltip", "Click to edit the selected service."));
         ui.editButton->setWhatsThis(i18nc("@info:whatsthis",
                                           "Click this button to edit the settings of the currently selected directory service. "
@@ -225,7 +228,7 @@ public:
         ui.editButton->setEnabled(false);
         groupsButtonLayout->addWidget(ui.editButton);
 
-        ui.deleteButton = new QPushButton(i18nc("@action:button", "Delete"));
+        ui.deleteButton = new QPushButton(i18nc("@action:button", "Delete"), q);
         ui.deleteButton->setToolTip(i18nc("@info:tooltip", "Click to remove the selected service."));
         ui.deleteButton->setWhatsThis(i18nc("@info:whatsthis",
                                             "Click this button to remove the currently selected directory service. "
