@@ -32,6 +32,13 @@ void information(QWidget *parent,
                  const QString &title = {},
                  KMessageBox::Options options = KMessageBox::Notify);
 
+KLEO_EXPORT
+void informationWId(WId parentId,
+                    const QString &text,
+                    const Kleo::AuditLogEntry &auditLog,
+                    const QString &title = {},
+                    KMessageBox::Options options = KMessageBox::Notify);
+
 KLEO_EXPORT
 void error(QWidget *parent,
            const QString &text,
@@ -40,8 +47,10 @@ void error(QWidget *parent,
            KMessageBox::Options options = KMessageBox::Notify);
 
 KLEO_EXPORT
-KLEO_DEPRECATED_VERSION(5, 23, "Use AuditLogViewer::showAuditLog()")
-void auditLog(QWidget *parent, const QString &log, const QString &title = {});
-
+void errorWId(WId parentId,
+              const QString &text,
+              const Kleo::AuditLogEntry &auditLog,
+              const QString &title = {},
+              KMessageBox::Options options = KMessageBox::Notify);
 }
 }
